Files
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

115 lines
3.1 KiB
C++

/*
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
*
* SPDX-License-Identifier: MIT
*/
#include <hip_test_common.hh>
#include <performance_common.hh>
/**
* @addtogroup stream stream
* @{
* @ingroup PerformanceTestStream
*/
#if HT_NVIDIA
static int IsStreamWriteValueSupported(int device_id) {
int write_value_supported = 0;
cuDeviceGetAttribute(&write_value_supported, CU_DEVICE_ATTRIBUTE_CAN_USE_64_BIT_STREAM_MEM_OPS,
device_id);
return write_value_supported;
}
#endif
class StreamWriteValue32Benchmark : public Benchmark<StreamWriteValue32Benchmark> {
public:
void operator()(const size_t array_size) {
const StreamGuard stream_guard{Streams::created};
const hipStream_t stream = stream_guard.stream();
uint32_t* value_ptr;
uint32_t value{0};
HIP_CHECK(hipMalloc(&value_ptr, sizeof(uint32_t) * array_size));
HIP_CHECK(hipMemset(value_ptr, value, sizeof(uint32_t) * array_size));
TIMED_SECTION(kTimerTypeCpu) { HIP_CHECK(hipStreamWriteValue32(stream, value_ptr, value, 0)); }
HIP_CHECK(hipFree(value_ptr));
}
};
class StreamWriteValue64Benchmark : public Benchmark<StreamWriteValue64Benchmark> {
public:
void operator()(const size_t array_size) {
const StreamGuard stream_guard{Streams::created};
const hipStream_t stream = stream_guard.stream();
uint64_t* value_ptr;
uint64_t value{0};
HIP_CHECK(hipMalloc(&value_ptr, sizeof(uint64_t) * array_size));
HIP_CHECK(hipMemset(value_ptr, value, sizeof(uint64_t) * array_size));
TIMED_SECTION(kTimerTypeCpu) { HIP_CHECK(hipStreamWriteValue64(stream, value_ptr, value, 0)); }
HIP_CHECK(hipFree(value_ptr));
}
};
template <typename WriteValueBenchmark> static void RunBenchmark(const size_t array_size) {
WriteValueBenchmark benchmark;
benchmark.AddSectionName(std::to_string(array_size));
benchmark.Run(array_size);
}
/**
* Test Description
* ------------------------
* - Executes `hipStreamWriteValue32`:
* -# Allocation size:
* - 4 KB
* - 4 MB
* - 16 MB
* Test source
* ------------------------
* - performance/api/stream/hipStreamWriteValue.cc
* Test requirements
* ------------------------
* - HIP_VERSION >= 5.2
*/
HIP_TEST_CASE(Performance_hipStreamWriteValue32) {
#if HT_AMD
size_t array_size = GENERATE(4_KB, 4_MB, 16_MB);
RunBenchmark<StreamWriteValue32Benchmark>(array_size);
#endif
}
/**
* Test Description
* ------------------------
* - Executes `hipStreamWriteValue64`:
* -# Allocation size:
* - 4 KB
* - 4 MB
* - 16 MB
* Test source
* ------------------------
* - performance/api/stream/hipStreamWriteValue.cc
* Test requirements
* ------------------------
* - HIP_VERSION >= 5.2
*/
HIP_TEST_CASE(Performance_hipStreamWriteValue64) {
#if HT_NVIDIA
if (!IsStreamWriteValueSupported(0)) {
HIP_SKIP_TEST(
"GPU 0 doesn't support hipStreamWriteValue64() function. "
"Hence skipping the testing with Pass result.");
}
#endif
size_t array_size = GENERATE(4_KB, 4_MB, 16_MB);
RunBenchmark<StreamWriteValue64Benchmark>(array_size);
}
/**
* End doxygen group PerformanceTest.
* @}
*/